import React from 'react';
import SimpleInput from '~/driven/utils/components/inputs/simple-input/SimpleInput';
import InputBox from '~/driven/utils/components/inputs/select-box/InputBox';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import { ICreatePlaceProps, placeTypes } from './protocol';

export default function CreatePlaceView(props: ICreatePlaceProps) {
  const { formStateData, handleNameSetState } = props;
  const { formState, setFormState } = formStateData;

  const PlacesOptions = Object.keys(placeTypes).map((placeTypeKey) => {
    const key = placeTypeKey as keyof typeof placeTypes;

    return { value: placeTypes[key], label: staticMessages.placeTypes[placeTypes[key]] };
  });
  return (
    <form className='p-4 py-6 flex flex-wrap w-full gap-4'>
      <SimpleInput
        inputData={{
          name: staticMessages.global.PlaceName,
          title: staticMessages.global.PlaceName,
        }}
        stateHanlder={{
          state: formState.placeName,
          setState: handleNameSetState,
        }}
        className='mb-4 w-[48%] px-2'
      />
      <InputBox
        name={staticMessages.global.placeType}
        state={{
          value: { value: placeTypes.continent, label: staticMessages.placeTypes[placeTypes.continent] },
          setValue: (newValue: `${placeTypes}`) => setFormState((prev) => ({ ...prev, placeTypes: newValue })),
          options: PlacesOptions,
        }}
        title={staticMessages.global.placeType}
        className='mb-4 w-[48%] px-2 border-1 border-txt-medium'
      />
    </form>
  );
}
